@@ -15,8 +15,9 @@ function(FILEPATH,PARAMETERS,NUMRUNSPERSAMPLE,MEASURES,RESULTFILENAME,ALTERNATIV
 			# NOW ALL THE MEDIANS ARE HELD TOGETHER, ACCOMPANIED BY THEIR SIMULATION PARAMETERS BEING ANALYSED
 			ALL_MEDIAN_RESULTS<-NULL
 			
+			# No longer used, as changed in reading of CSV files (check.names=FALSE)
 			# Check the Measures and Parameters for Spaces - R will have replaced these with a dot
-			MEASURES<-table_header_check(MEASURES)
+			#MEASURES<-table_header_check(MEASURES)
 
 			# THE WAY WE DO OUR SIMULATIONS, WITH THE OLD FOLDER STRUCTURE, THE BASELINE WILL BE SIMULATED FOR EACH PARAMETER IN
 			# ROBUSTNESS ANALYSIS. THERE IS NO NEED TO PERFORM THE ANALYSIS AGAIN AND AGAIN (AS WOULD HAPPEN WHEN WE INCREMENT THROUGH
